@@ -3,6 +3,7 @@
 """
     国家自然科学基金查询系统
 """
+import os
 import sys
 import json
 
@@ -25,9 +26,8 @@ if PY2:
     sys.setdefaultencoding('utf-8')
 
 
-__version__ = '1.0.2'
-__author__ = 'suqingdong'
-__author_email__ = '1078595229@qq.com'
+BASE_DIR = os.path.dirname(os.path.realpath(__file__))
+version_info = json.load(open(os.path.join(BASE_DIR, 'version', 'version.json')))
 
 
 class NSFC(object):
@@ -155,14 +155,13 @@ class NSFC(object):
             查询结果转成字典
         """
         header = '项目名称 批准号 项目类别 依托单位 项目负责人 资助经费(万元) 批准年度 关键词 是否结题 研究成果(期刊论文;会议论文;著作;奖励;专利) 依托单位ID 项目负责人ID 项目类别代码 申请代码 起止年月'.split()
-        context = OrderedDict()
-
-        for each in header:
-            context[each] = ''     
 
         for data in query_result:
             for row in data['data']['resultsData']:
                 tmp = dict(zip(header, row[1:]))
+
+                context = OrderedDict()
+                [context.update(h='') for h in header]
                 context.update(tmp)
 
                 conclusion_context = {}
